# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ResourceRestrictions(str, enum.Enum):
    ACCOUNTS = "accounts"
    INTEGRATIONS = "integrations"

    def visit(self, accounts: typing.Callable[[], T_Result], integrations: typing.Callable[[], T_Result]) -> T_Result:
        if self is ResourceRestrictions.ACCOUNTS:
            return accounts()
        if self is ResourceRestrictions.INTEGRATIONS:
            return integrations()
