# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ....core.datetime_utils import serialize_datetime
from .teams_credential import TeamsCredential

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class NotificationsTeams(pydantic.BaseModel):
    """
    Configuration for sending messages to Microsoft Teams. This provider can be configured as a public webhook or with OAuth.
    """

    channel_id: str = pydantic.Field()
    """
    The ID of the channel to send messages to.
    """

    credential: TeamsCredential
    endpoint: typing.Optional[str] = pydantic.Field(default=None)
    """
    The URL of the endpoint to send messages to. Only specified here if OAuth. For public, please refer to TeamsCredential.
    """

    team_id: str = pydantic.Field()
    """
    The ID of the team to send messages to.
    """

    tenant_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Azure Directory (tenant) ID. Only if OAuth is used.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}
