# This file was auto-generated by Fern from our API Definition.

from .....v_1_3_0.resources.authentication.resources.classes.types.authentication import (
    Authentication as resources_ocsf_resources_v_1_3_0_resources_authentication_resources_classes_types_authentication_Authentication,
)

Authentication = (
    resources_ocsf_resources_v_1_3_0_resources_authentication_resources_classes_types_authentication_Authentication
)
