# This file was auto-generated by Fern from our API Definition.

from .common_properties import CommonProperties
from .external_reference import ExternalReference
from .granular_marking import GranularMarking
from .id import Id
from .identity import Identity
from .kill_chain_phase import KillChainPhase
from .marking_definition import MarkingDefinition
from .relationships import Relationships
from .software import Software

__all__ = [
    "CommonProperties",
    "ExternalReference",
    "GranularMarking",
    "Id",
    "Identity",
    "KillChainPhase",
    "MarkingDefinition",
    "Relationships",
    "Software",
]
