# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class RemoteFieldTypeId(str, enum.Enum):
    STRING = "string"
    NUMBER = "number"
    ENUM = "enum"
    OTHER = "other"

    def visit(
        self,
        string: typing.Callable[[], T_Result],
        number: typing.Callable[[], T_Result],
        enum: typing.Callable[[], T_Result],
        other: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is RemoteFieldTypeId.STRING:
            return string()
        if self is RemoteFieldTypeId.NUMBER:
            return number()
        if self is RemoteFieldTypeId.ENUM:
            return enum()
        if self is RemoteFieldTypeId.OTHER:
            return other()
