# This file was auto-generated by Fern from our API Definition.

from .....v_1_3_0.resources.inventoryinfo.resources.classes.types.inventory_info import (
    InventoryInfo as resources_ocsf_resources_v_1_3_0_resources_inventoryinfo_resources_classes_types_inventory_info_InventoryInfo,
)

InventoryInfo = (
    resources_ocsf_resources_v_1_3_0_resources_inventoryinfo_resources_classes_types_inventory_info_InventoryInfo
)
