# This file was auto-generated by Fern from our API Definition.

from .....v_1_3_0.resources.compliancefinding.resources.classes.types.compliance_finding import (
    ComplianceFinding as resources_ocsf_resources_v_1_3_0_resources_compliancefinding_resources_classes_types_compliance_finding_ComplianceFinding,
)

ComplianceFinding = resources_ocsf_resources_v_1_3_0_resources_compliancefinding_resources_classes_types_compliance_finding_ComplianceFinding
