# This file was auto-generated by Fern from our API Definition.

from .....v_1_3_0.resources.groupmanagement.resources.classes.types.group_management import (
    GroupManagement as resources_ocsf_resources_v_1_3_0_resources_groupmanagement_resources_classes_types_group_management_GroupManagement,
)

GroupManagement = (
    resources_ocsf_resources_v_1_3_0_resources_groupmanagement_resources_classes_types_group_management_GroupManagement
)
