# This file was auto-generated by Fern from our API Definition.

from .....v_1_3_0.resources.webresourceaccessactivity.resources.classes.types.web_resource_access_activity import (
    WebResourceAccessActivity as resources_ocsf_resources_v_1_3_0_resources_webresourceaccessactivity_resources_classes_types_web_resource_access_activity_WebResourceAccessActivity,
)

WebResourceAccessActivity = resources_ocsf_resources_v_1_3_0_resources_webresourceaccessactivity_resources_classes_types_web_resource_access_activity_WebResourceAccessActivity
