# This file was auto-generated by Fern from our API Definition.

from .....v_1_3_0.resources.accountchange.resources.classes.types.account_change import (
    AccountChange as resources_ocsf_resources_v_1_3_0_resources_accountchange_resources_classes_types_account_change_AccountChange,
)

AccountChange = (
    resources_ocsf_resources_v_1_3_0_resources_accountchange_resources_classes_types_account_change_AccountChange
)
