# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ListConnectorCapabilitiesExpandOptions(str, enum.Enum):
    PROVIDERS = "providers"

    def visit(self, providers: typing.Callable[[], T_Result]) -> T_Result:
        if self is ListConnectorCapabilitiesExpandOptions.PROVIDERS:
            return providers()
