# This file was auto-generated by Fern from our API Definition.

from .....v_1_3_0.resources.incidentfinding.resources.classes.types.incident_finding import (
    IncidentFinding as resources_ocsf_resources_v_1_3_0_resources_incidentfinding_resources_classes_types_incident_finding_IncidentFinding,
)

IncidentFinding = (
    resources_ocsf_resources_v_1_3_0_resources_incidentfinding_resources_classes_types_incident_finding_IncidentFinding
)
