# This file was auto-generated by Fern from our API Definition.

from .types import (
    CommonProperties,
    ExternalReference,
    GranularMarking,
    Id,
    Identity,
    KillChainPhase,
    MarkingDefinition,
    Relationships,
    Software,
)

__all__ = [
    "CommonProperties",
    "ExternalReference",
    "GranularMarking",
    "Id",
    "Identity",
    "KillChainPhase",
    "MarkingDefinition",
    "Relationships",
    "Software",
]
