# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .nucleus_finding_state import NucleusFindingState


class ProviderSpecificFindingState_Nucleus(NucleusFindingState):
    type: typing.Literal["nucleus"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


ProviderSpecificFindingState = typing.Union[ProviderSpecificFindingState_Nucleus]
