# This file was auto-generated by Fern from our API Definition.

from ...ocsf.resources.v_1_3_0.resources.softwareinfo.resources.classes.types.software_info import SoftwareInfo

Application = SoftwareInfo
