# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class QueryStatus(str, enum.Enum):
    PENDING = "PENDING"
    COMPLETE = "COMPLETE"

    def visit(self, pending: typing.Callable[[], T_Result], complete: typing.Callable[[], T_Result]) -> T_Result:
        if self is QueryStatus.PENDING:
            return pending()
        if self is QueryStatus.COMPLETE:
            return complete()
