# This file was auto-generated by Fern from our API Definition.

from .....v_1_3_0.resources.processactivity.resources.classes.types.process_activity import (
    ProcessActivity as resources_ocsf_resources_v_1_3_0_resources_processactivity_resources_classes_types_process_activity_ProcessActivity,
)

ProcessActivity = (
    resources_ocsf_resources_v_1_3_0_resources_processactivity_resources_classes_types_process_activity_ProcessActivity
)
