# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from ...credentials.types.bridge_token_credential import BridgeTokenCredential
from ...credentials.types.bridge_token_credential_id import BridgeTokenCredentialId

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class SplunkBridgeHecToken_BridgeToken(BridgeTokenCredential):
    type: typing.Literal["bridge_token"]

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True


class SplunkBridgeHecToken_BridgeTokenId(pydantic.BaseModel):
    type: typing.Literal["bridge_token_id"]
    value: BridgeTokenCredentialId

    class Config:
        frozen = True
        smart_union = True


SplunkBridgeHecToken = typing.Union[SplunkBridgeHecToken_BridgeToken, SplunkBridgeHecToken_BridgeTokenId]
