# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ManagedType(str, enum.Enum):
    MANAGED = "Managed"
    UNMANAGED = "Unmanaged"

    def visit(self, managed: typing.Callable[[], T_Result], unmanaged: typing.Callable[[], T_Result]) -> T_Result:
        if self is ManagedType.MANAGED:
            return managed()
        if self is ManagedType.UNMANAGED:
            return unmanaged()
