# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AuditActions(str, enum.Enum):
    LIST = "list"
    ALL = "*"

    def visit(self, list_: typing.Callable[[], T_Result], all_: typing.Callable[[], T_Result]) -> T_Result:
        if self is AuditActions.LIST:
            return list_()
        if self is AuditActions.ALL:
            return all_()
