# This file was auto-generated by Fern from our API Definition.

import typing

from ...capabilities_base.types.category_id import CategoryId
from .connector import Connector

ConnectorOrId = typing.Union[CategoryId, Connector]
