# This file was auto-generated by Fern from our API Definition.

from ...ocsf.resources.v_1_3_0.resources.inventoryinfo.resources.classes.types.inventory_info import InventoryInfo

Device = InventoryInfo
