# This file was auto-generated by Fern from our API Definition.

from .....v_1_3_0.resources.detectionfinding.resources.classes.types.detection_finding import (
    DetectionFinding as resources_ocsf_resources_v_1_3_0_resources_detectionfinding_resources_classes_types_detection_finding_DetectionFinding,
)

DetectionFinding = resources_ocsf_resources_v_1_3_0_resources_detectionfinding_resources_classes_types_detection_finding_DetectionFinding
