# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AuditType(str, enum.Enum):
    ALARM = "ALARM"
    ERROR = "ERROR"
    API = "API"
    UNKNOWN = "UNKNOWN"

    def visit(
        self,
        alarm: typing.Callable[[], T_Result],
        error: typing.Callable[[], T_Result],
        api: typing.Callable[[], T_Result],
        unknown: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is AuditType.ALARM:
            return alarm()
        if self is AuditType.ERROR:
            return error()
        if self is AuditType.API:
            return api()
        if self is AuditType.UNKNOWN:
            return unknown()
