# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class OrganizationType(str, enum.Enum):
    ROOT = "root"
    STANDARD = "standard"

    def visit(self, root: typing.Callable[[], T_Result], standard: typing.Callable[[], T_Result]) -> T_Result:
        if self is OrganizationType.ROOT:
            return root()
        if self is OrganizationType.STANDARD:
            return standard()
